@@ -3,7 +3,7 @@ from .models import Person
 
 class PersonAdmin( admin.ModelAdmin ):
 	list_display = ( 'name', 'ssn', 'address', 'postcode', 'blocked' )
-	list_filter = ('sex',)
+	list_filter = ('sex', 'postcode')
 	search_fields = ('name', 'ssn')
 	
 admin.site.register( Person, PersonAdmin )
\ No newline at end of file
